@@ -1,8 +1,11 @@
+mod compliance_job;
 mod entity;
 mod expansions;
+mod geo;
 mod list;
 mod media;
-mod metric;
+mod place;
+mod poll;
 mod space;
 mod stream_rule;
 mod tweet;
@@ -11,11 +14,14 @@ mod user;
 mod verb;
 mod withheld;
 
+pub use compliance_job::*;
 pub use entity::*;
 pub use expansions::*;
+pub use geo::*;
 pub use list::*;
 pub use media::*;
-pub use metric::*;
+pub use place::*;
+pub use poll::*;
 pub use space::*;
 pub use stream_rule::*;
 pub use tweet::*;
