@@ -1,17 +1,21 @@
 mod builder;
+mod compliance_job;
 mod exclude;
 mod expansions;
 mod fields;
 mod granularity;
 mod macros;
 mod sort_order;
+mod space_state;
 mod to_query;
 
 pub use builder::*;
+pub use compliance_job::*;
 pub use exclude::*;
 pub use expansions::*;
 pub use fields::*;
 pub use granularity::*;
 pub(crate) use macros::*;
 pub use sort_order::*;
+pub use space_state::*;
 pub(crate) use to_query::*;
